import { JsonRpcProvider } from '@pokt-foundation/pocketjs-provider';
import { AbstractSigner, KeyManager } from '@pokt-foundation/pocketjs-signer';
import { HTTPMethod, Node, PocketAAT, RelayHeaders, Session } from '@pokt-foundation/pocketjs-types';
import { AbstractRelayer } from './abstract-relayer';
export declare class Relayer implements AbstractRelayer {
    readonly keyManager: KeyManager | AbstractSigner;
    readonly provider: JsonRpcProvider;
    readonly dispatchers: string[];
    constructor({ keyManager, provider, dispatchers }: {
        keyManager: any;
        provider: any;
        dispatchers: any;
    });
    getNewSession({ applicationPubKey, chain, sessionBlockHeight, options, }: {
        applicationPubKey?: string;
        chain: string;
        sessionBlockHeight?: number;
        options?: {
            retryAttempts?: number;
            rejectSelfSignedCertificates?: boolean;
            timeout?: number;
        };
    }): Promise<Session>;
    static relay({ blockchain, data, headers, keyManager, method, node, path, pocketAAT, provider, session, timeout, }: {
        blockchain: string;
        data: string;
        headers?: RelayHeaders | null;
        keyManager: KeyManager | AbstractSigner;
        method: HTTPMethod | '';
        node: Node;
        path: string;
        pocketAAT: PocketAAT;
        provider: JsonRpcProvider;
        session: Session;
        timeout?: number;
    }): Promise<{
        response: any;
        relayProof: {
            entropy: number;
            sessionBlockheight: number;
            servicerPubKey: string;
            blockchain: string;
            aat: {
                version: string;
                appPubKey: string;
                clientPubKey: string;
                signature: string;
            };
            signature: any;
            requestHash: string;
        };
        serviceNode: Node;
    }>;
    relay({ blockchain, data, headers, method, node, path, pocketAAT, session, timeout, }: {
        data: string;
        blockchain: string;
        pocketAAT: PocketAAT;
        headers?: RelayHeaders | null;
        method: HTTPMethod | '';
        session: Session;
        node: Node;
        path: string;
        timeout?: number;
    }): Promise<{
        response: any;
        relayProof: {
            entropy: number;
            sessionBlockheight: number;
            servicerPubKey: string;
            blockchain: string;
            aat: {
                version: string;
                appPubKey: string;
                clientPubKey: string;
                signature: string;
            };
            signature: any;
            requestHash: string;
        };
        serviceNode: Node;
    }>;
    static getRandomSessionNode(session: Session): Node;
    static isNodeInSession(session: Session, node: Node): boolean;
    static generateProofBytes({ entropy, sessionBlockHeight, servicerPublicKey, blockchain, pocketAAT, requestHash, }: {
        entropy: bigint | string | number;
        sessionBlockHeight: string | number;
        servicerPublicKey: string;
        blockchain: string;
        pocketAAT: PocketAAT;
        requestHash: any;
    }): string;
    static hashAAT(aat: PocketAAT): string;
    static hashRequest(requestHash: any): string;
}
//# sourceMappingURL=relayer.d.ts.map